From 91243ee427a910ac36e784b9001e4adc0ad6efa0 Mon Sep 17 00:00:00 2001
From: Daniel Gustafsson <daniel@yesql.se>
Date: Fri, 20 Aug 2021 14:08:46 +0200
Subject: [PATCH 1/2] Fix variable shadowing

The progname parameter shadows the global variable of the same name
which will cause static analyzers to complain.  Fix by renaming the
local variable.
---
 src/bin/pg_amcheck/pg_amcheck.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/bin/pg_amcheck/pg_amcheck.c b/src/bin/pg_amcheck/pg_amcheck.c
index f4b1ef95e9..87c62a3b71 100644
--- a/src/bin/pg_amcheck/pg_amcheck.c
+++ b/src/bin/pg_amcheck/pg_amcheck.c
@@ -179,7 +179,7 @@ static void run_command(ParallelSlot *slot, const char *sql);
 static bool verify_heap_slot_handler(PGresult *res, PGconn *conn,
 									 void *context);
 static bool verify_btree_slot_handler(PGresult *res, PGconn *conn, void *context);
-static void help(const char *progname);
+static void help(const char *program_name);
 static void progress_report(uint64 relations_total, uint64 relations_checked,
 							uint64 relpages_total, uint64 relpages_checked,
 							const char *datname, bool force, bool finished);
@@ -1138,14 +1138,14 @@ verify_btree_slot_handler(PGresult *res, PGconn *conn, void *context)
  *
  * Prints help page for the program
  *
- * progname: the name of the executed program, such as "pg_amcheck"
+ * program_name: the name of the executed program, such as "pg_amcheck"
  */
 static void
-help(const char *progname)
+help(const char *program_name)
 {
-	printf(_("%s checks objects in a PostgreSQL database for corruption.\n\n"), progname);
+	printf(_("%s checks objects in a PostgreSQL database for corruption.\n\n"), program_name);
 	printf(_("Usage:\n"));
-	printf(_("  %s [OPTION]... [DBNAME]\n"), progname);
+	printf(_("  %s [OPTION]... [DBNAME]\n"), program_name);
 	printf(_("\nTarget options:\n"));
 	printf(_("  -a, --all                       check all databases\n"));
 	printf(_("  -d, --database=PATTERN          check matching database(s)\n"));
-- 
2.24.3 (Apple Git-128)

